// Ionic Starter App

// angular.module is a global place for creating, registering and retrieving Angular modules
// 'starter' is the name of this angular module example (also set in a <body> attribute in index.html)
// the 2nd parameter is an array of 'requires'
// 'starter.controllers' is found in controllers.js

angular.module('Dentalink', ['ionic', 'Dentalink.controllers', 'Dentalink.services', 'pascalprecht.translate', 'ngCordova'])

.run(function($ionicPlatform, $translate) {
  $ionicPlatform.ready(function() {
    // Hide the accessory bar by default (remove this to show the accessory bar above the keyboard
    // for form inputs)
    /* 
    if (window.cordova && window.cordova.plugins.Keyboard) {
      cordova.plugins.Keyboard.hideKeyboardAccessoryBar(true);
    }
    */
    if (window.StatusBar) {
      // org.apache.cordova.statusbar required
      StatusBar.styleDefault();
    }
    // Translate
    if(typeof navigator.globalization !== "undefined") {
        navigator.globalization.getPreferredLanguage(function(language) {
            $translate.use((language.value).split("-")[0]).then(function(data) {
                console.log("[SUCCESS] Lang -> " + data);
            }, function(error) {
                console.log("[ERROR] Lang -> " + error);
            });
        }, null);
    }
  });
})

.config(function($stateProvider, $urlRouterProvider, $translateProvider, $ionicConfigProvider, $compileProvider) {

  $stateProvider

  .state('login', {
      url: '/login',
      templateUrl: 'templates/login.html',
      controller: 'LoginCtrl'
  })
  .state('logout', {
      url: '/logout',
      templateUrl: 'templates/logout.html',
      controller: 'LogoutCtrl'
  })
  .state('sesion', {
      url: '/sesion',
      controller: 'SesionCtrl'
  })
  .state('tutorial', {
      url: '/tutorial',
      templateUrl: 'templates/tutorial.html',
      controller: 'TutorialCtrl'
  })
  .state('app', {
    url: "/app",
    abstract: true,
    templateUrl: "templates/menu.html",
    controller: 'AppCtrl'
  })

  .state('app.liquidaciones', {
    url: "/liquidaciones",
    views: {
      'menuContent': {
        templateUrl: "templates/liquidaciones.html",
        controller: 'LiquidacionesCtrl'
      }
    }
  })
  .state('app.config', {
    url: "/config",
    views: {
      'menuContent': {
        templateUrl: "templates/config.html",
        controller: 'ConfigCtrl'
      }
    }
  })
    .state('app.agenda', {
      url: "/agenda",
      views: {
        'menuContent': {
          templateUrl: "templates/agenda.html",
          controller: 'AgendaCtrl'
        }
      }
    })

  .state('app.plandetratamiento', {
    url: "/agenda/:agendaId/:agendaIdPDT/:agendaFecha/:agendaIdPaciente/:agendaNombre",
    views: {
      'menuContent': {
        templateUrl: "templates/plandetratamiento.html",
        controller: 'PlanDeTratamientoCtr'
      }
    }
  });
  // if none of the above states are matched, use this as the fallback
  $urlRouterProvider.otherwise('/sesion');
  // Translate
  $translateProvider.translations('es_CL', lang_es_CL);
  $translateProvider.translations('es_BO', lang_es_BO);
  $translateProvider.translations('es_CO', lang_es_CO);
  $translateProvider.translations('es_EC', lang_es_EC);
  $translateProvider.translations('es_MX', lang_es_MX);
  $translateProvider.translations('es_PE', lang_es_PE);
  $translateProvider.preferredLanguage("es_CL");
  $translateProvider.fallbackLanguage("es_CL");
  $translateProvider.useSanitizeValueStrategy('escape');

  $ionicConfigProvider.tabs.position('bottom'); // Fija el tab abajo para todos (conflictos con android, que por defecto es para arriba)
  $ionicConfigProvider.navBar.alignTitle('middle');
  $ionicConfigProvider.views.swipeBackEnabled(false);

  // Santizizacion de src de img para evitar XSS
  //$compileProvider.imgSrcSanitizationWhitelist('img/');


})
// Formateador de dinero 
.filter('money', [
function() { 
    return function(n, z, t, c, d){ // n: monto, z: simbolo, t: separador de miles, c: cantidad de decimales, d: separador de decimales
      var c = isNaN(c = Math.abs(c)) ? 2 : c, 
          d = d == undefined ? "." : d, 
          t = t == undefined ? "," : t, 
          s = n < 0 ? "-" : "", 
          i = parseInt(n = Math.abs(+n || 0).toFixed(c)) + "", 
          j = (j = i.length) > 3 ? j % 3 : 0;
         return z + s + (j ? i.substr(0, j) + t : "") + i.substr(j).replace(/(\d{3})(?=\d)/g, "$1" + t) + (c ? d + Math.abs(n - i).toFixed(c).slice(2) : "");
       };
    }])
.filter('truncate', function () {
      return function (value, wordwise, max, tail) {
          if (!value) return '';

          max = parseInt(max, 10);
          if (!max) return value;
          if (value.length <= max) return value;

          value = value.substr(0, max);
          if (wordwise) {
              var lastspace = value.lastIndexOf(' ');
              if (lastspace != -1) {
                  value = value.substr(0, lastspace);
              }
          }

          return value + (tail || ' …');
      };
  })
.filter('citasDia', function(){
  return function(data, dia, caso){
    var arrayDia = [];
    if (!data) return arrayDia;
    if (!caso){
      for(var i = 0; i< data.length;i++){
        if (data[i].fecha == dia && data[i].id != ''){
          arrayDia.push(data[i]);
        }
      }
    }
    else{
      for(var i = 0; i< data.length;i++){
        if (data[i].fecha == dia && data[i].id == ''){
          arrayDia.push(data[i]);
        }
      }
    }
    console.log(arrayDia);
    return arrayDia;
  }
})
;
