angular.module('Dentalink.services', [])
// Servicios de llamados a la API
.service('LoginService', function($q, $http, $ionicLoading, errorService) {
    return {
        loginUser: function(name, pw, clinica) {
            var deferred = $q.defer();
            var promise = deferred.promise;
            $ionicLoading.show({
                template: '<ion-spinner></ion-spinner>',
            });
            $http.defaults.headers.post["Content-Type"] = "application/x-www-form-urlencoded";
            $http.post(window.DL_API_URL+'api/2/sessions', "user=" + name + "&password=" + pw + "&platform=" + clinica)
            .success(function(data) {
                console.log(data);
                deferred.resolve(data);
                $ionicLoading.hide();
            })
            .error(function(data) {
                errorService.showAlertLogin(data);
                deferred.reject('login_error');
                $ionicLoading.hide();
            });
            promise.success = function(fn) {
                promise.then(fn);
                return promise;
            }
            promise.error = function(fn) {
                promise.then(null, fn);
                return promise;
            }
            return promise;
        }
    }
})
.service('agendaService', function($q, $http, $ionicLoading, $state, $translate, $ionicPopup, errorService){
    return{
        getAgendamientosSemanal: function(token, fecha, sucursal) {
            var deferred = $q.defer();
            var promise = deferred.promise;
            $ionicLoading.show({
              template: '<ion-spinner></ion-spinner>',
            });
            $http.get(window.DL_API_URL+'api/2/appointments', { params: { 'fecha':fecha, 'key': token, 'sucursal': sucursal } })
            .success(function(data) {
                var datos = JSON.stringify(data);
                deferred.resolve(datos);
                $ionicLoading.hide();
            })
            .error(function(data) {
                $ionicLoading.hide();
                errorService.showAlert(data);
                deferred.reject('agenda_error'); // Mostramos el error localizado 
                console.log(data);
            }); 
            promise.success = function(fn) {
                promise.then(fn);
                return promise;
            }
            promise.error = function(fn) {
                promise.then(null, fn);
                return promise;
            }
            return promise;
        }
    }
})
.service('darCitaService', function($q, $http, $ionicLoading, $state, $translate, $ionicPopup, errorService){
    return{
        buscarPaciente: function(token, fecha, sucursal, id_dentista, hora, rut) {
            var deferred = $q.defer();
            var promise = deferred.promise;

            $ionicLoading.show({
              template: '<ion-spinner></ion-spinner>',
            });
            $http.post(window.DL_API_URL+'api/2/appointments/processSchedule?key=' + token + '&fecha=' + fecha + '&sucursal=' + sucursal + '&id_dentista=' + id_dentista + '&hora=' + hora + '&rut=' +rut)
            .success(function(data) {
                deferred.resolve(data);
                $ionicLoading.hide();
            })
            .error(function(data, status, headers, config) {
                $ionicLoading.hide();
                if (status == 412){
                    //console.log(data);
                    var datos = {};
                    datos.planes = data.presupuestos;
                    datos.cliente = data.cliente;
                    datos.status = 412;
                    deferred.reject(datos);
                }
                else if (status == 404){
                    var datos = {};
                    datos.content = data;
                    datos.status = 404;
                    deferred.reject(datos);
                }
                else if (status == 409){
                    var datos = {};
                    datos.content = data;
                    datos.status = 409;
                    deferred.reject(datos);
                }
                else{
                    errorService.showAlertAgendamiento(status);
                    deferred.reject(data);
                }
            }); 
            promise.success = function(fn) {
                promise.then(fn);
                return promise;
            }
            promise.error = function(fn) {
                promise.then(null, fn);
                return promise;
            }
            return promise;
        },
        darCitaPacienteNuevo: function(token, fecha, sucursal, id_dentista, hora, rut, nombre, apellidos, movil, mail){
            var deferred = $q.defer();
            var promise = deferred.promise;

            $ionicLoading.show({
              template: '<ion-spinner></ion-spinner>',
            });
            $http.post(window.DL_API_URL+'api/2/appointments/processSchedule?key=' + token + '&fecha=' + fecha + '&sucursal=' + sucursal + '&id_dentista=' + id_dentista + '&hora=' + hora + '&rut=' + rut + '&nombre=' + nombre + '&apellidos=' + apellidos + '&telefono_movil=' + movil + '&email=' +mail)
            .success(function(data) {
                deferred.resolve(data);
                $ionicLoading.hide();
            })
            .error(function(data, status, headers, config) {
                $ionicLoading.hide();
                if (status == 409){
                    var datos = {};
                    datos.content = data.cliente;
                    datos.status = 409;
                    deferred.reject(datos);
                }
                else{
                    errorService.showAlertAgendamiento(status);
                    deferred.reject(data);
                }
            });
            promise.success = function(fn) {
                promise.then(fn);
                return promise;
            }
            promise.error = function(fn) {
                promise.then(null, fn);
                return promise;
            }
            return promise;
        },
        darCitaPacienteExistente: function(token, fecha, sucursal, id_dentista, hora, rut, id_presupuesto){
            var deferred = $q.defer();
            var promise = deferred.promise;

            $ionicLoading.show({
              template: '<ion-spinner></ion-spinner>',
            });
            $http.post(window.DL_API_URL+'api/2/appointments/processSchedule?key=' + token + '&fecha=' + fecha + '&sucursal=' + sucursal + '&id_dentista=' + id_dentista + '&hora=' + hora + '&rut=' +rut+ '&id_presupuesto=' +id_presupuesto)
            .success(function(data) {
                deferred.resolve(data);
                $ionicLoading.hide();
            })
            .error(function(data, status, headers, config) {
                $ionicLoading.hide();
                if (status == 409){
                    var datos = {};
                    datos.content = data;
                    datos.status = 409;
                    deferred.reject(datos);
                }
                else{
                    errorService.showAlertAgendamiento(status);
                    deferred.reject(data);
                }
            });
            promise.success = function(fn) {
                promise.then(fn);
                return promise;
            }
            promise.error = function(fn) {
                promise.then(null, fn);
                return promise;
            }
            return promise;
        }
    }
})
.service('LiquidacionesService', function($q, $http, $timeout, $state, $ionicPopup, $translate, errorService) {
    return {
        getLiquidaciones: function(token, sucursal) {
            var deferred = $q.defer();
            var promise = deferred.promise;

            // Live reload issue 
            $http.get(window.DL_API_URL+'api/2/payrolls/0/details', { params: { 'key': token, 'sucursal': sucursal } })
            .success(function(data) {
                deferred.resolve(data);
            })
            .error(function(data) {
                errorService.showAlert(data);
                deferred.reject('liquidaciones_error'); // Mostramos el error localizado 
            }); 
            // Data de pruebas por live reload server issue 
            //var data = [{"fecha":"2015-07-10","nombre_cliente":"JUAN MARTINEZ","nombre_producto":"ARCADA SUPERIOR","total":"10307.04","estado":0},{"fecha":"2015-07-10","nombre_cliente":"JUAN MARTINEZ","nombre_producto":"Profilaxis","total":"454.45","estado":1},{"fecha":"2015-07-10","nombre_cliente":"JUAN MARTINEZ","nombre_producto":"Corona de Porcelana Premiun PLUS","total":"-292.87","estado":2},{"fecha":"2015-07-10","nombre_cliente":"JUAN MARTINEZ","nombre_producto":"Control Y Examen Periodico De Rigor","total":"16360.38","estado":0},{"fecha":"2015-07-10","nombre_cliente":"JUAN MARTINEZ","nombre_producto":"Interconsulta Con Informe Escrito 1 Sesion","total":"32720.76","estado":0},{"fecha":"2015-07-10","nombre_cliente":"JUAN MARTINEZ","nombre_producto":"Cirug\u00eda \u00f3sea Resectiva, Por Sextante","total":"109069.20","estado":0},{"fecha":"2015-07-10","nombre_cliente":"MARIO PEREZ","nombre_producto":"13015 Incrustaci\u00f3n Met\u00e1lica Simple","total":"52312.82","estado":0},{"fecha":"2015-07-10","nombre_cliente":"MARIO PEREZ","nombre_producto":"Resina Anterior Simple","total":"504.95","estado":0}]; 
            //deferred.resolve(data);      
            //$timeout( function(){deferred.resolve(data);}, 1500); // Pruebas para el spinner
            promise.success = function(fn) {
                promise.then(fn);
                return promise;
            }
            promise.error = function(fn) {
                promise.then(null, fn);
                return promise;
            }
            return promise;
        }
    }
})
.service('planDeTratamiento', function($q, $http, $ionicLoading, $state, $ionicPopup, $translate, errorService){
    return{
        getDataPdt: function(idS, token) {
            var deferred = $q.defer();
            var promise = deferred.promise;
            $ionicLoading.show({
              template: '<ion-spinner></ion-spinner>',
            });
            $http.get(window.DL_API_URL+'api/2/appointments/'+idS+'/treatment_details', { params: { 'key': token } })
            .success(function(data) {
                var datos = JSON.stringify(data);
                deferred.resolve(datos);
                $ionicLoading.hide();
            })
            .error(function(data) {
                $ionicLoading.hide();
                errorService.showAlert(data);
                deferred.reject('agenda_error'); // Mostramos el error localizado 
            }); 
            promise.success = function(fn) {
                promise.then(fn);
                return promise;
            }
            promise.error = function(fn) {
                promise.then(null, fn);
                return promise;
            }
            return promise;
        }, evolve: function(idS, token, sucursal, data, simbolo_evolucion, finalizar) {
            var deferred = $q.defer();
            var promise = deferred.promise;
            $ionicLoading.show({
              template: '<ion-spinner></ion-spinner>',
            });
            console.log(window.DL_API_URL+'api/2/treatment_details/'+idS+'/do');
            $http.defaults.headers.post["Content-Type"] = "application/x-www-form-urlencoded";
            $http.post(window.DL_API_URL+'api/2/treatment_details/'+idS+'/do', "key=" + token + "&sucursal=" + sucursal+ "&datos=" + data + "&simbolo_evolucion=" + simbolo_evolucion + "&finalizar_presupuesto=" + finalizar)
            .success(function(data) {
                var datos = JSON.stringify(data);
                deferred.resolve(datos);
                $ionicLoading.hide();
            })
            .error(function(data) {
                $ionicLoading.hide();
                errorService.showAlert(data);
                deferred.reject('pdt_modal_evo_error'); // Mostramos el error localizado 
            }); 
            promise.success = function(fn) {
                promise.then(fn);
                return promise;
            }
            promise.error = function(fn) {
                promise.then(null, fn);
                return promise;
            }
            return promise;
        }, undo: function(idS, token) {
            var deferred = $q.defer();
            var promise = deferred.promise;
            $ionicLoading.show({
              template: '<ion-spinner></ion-spinner>',
            });
            console.log(window.DL_API_URL+'api/2/treatment_details/'+idS+'/undo');
            $http.defaults.headers.post["Content-Type"] = "application/x-www-form-urlencoded";
            $http.post(window.DL_API_URL+'api/2/treatment_details/'+idS+'/undo', "key=" + token)
            .success(function(data) {
                console.log(data);
                var datos = JSON.stringify(data);
                deferred.resolve(datos);
                $ionicLoading.hide();
            })
            .error(function(data) {
                $ionicLoading.hide();
                deferred.reject(data); // Mostramos el error localizado 
            }); 
            promise.success = function(fn) {
                promise.then(fn);
                return promise;
            }
            promise.error = function(fn) {
                promise.then(null, fn);
                return promise;
            }
            return promise;
        }
    }
})
.service('evoluciones', function($q, $http, $ionicLoading, $state, $ionicPopup, $translate, errorService){
    return{
        getDataPdt: function(idS, token) {
            var deferred = $q.defer();
            var promise = deferred.promise;
            $ionicLoading.show({
              template: '<ion-spinner></ion-spinner>',
            });
            $http.get(window.DL_API_URL+'api/2/appointments/'+idS+'/treatment_evolutions', { params: { 'key': token } })
            .success(function(data) {
                var datos = JSON.stringify(data);
                deferred.resolve(datos);
                $ionicLoading.hide();
            })
            .error(function(data) {
                $ionicLoading.hide();
                errorService.showAlert(data);
                deferred.reject('agenda_error'); // Mostramos el error localizado 
            }); 
            promise.success = function(fn) {
                promise.then(fn);
                return promise;
            }
            promise.error = function(fn) {
                promise.then(null, fn);
                return promise;
            }
            return promise;
        }, evolve: function(idS, token, data) {
            var deferred = $q.defer();
            var promise = deferred.promise;
            $ionicLoading.show({
              template: '<ion-spinner></ion-spinner>',
            });
            console.log(window.DL_API_URL+'api/2/appointments/'+idS+'/treatment_evolutions');
            $http.defaults.headers.post["Content-Type"] = "application/x-www-form-urlencoded";
            $http.post(window.DL_API_URL+'api/2/appointments/'+idS+'/treatment_evolutions', "key=" + token + "&datos=" + data)
            .success(function(data) {
                var datos = JSON.stringify(data);
                deferred.resolve(datos);
                $ionicLoading.hide();
            })
            .error(function(data) {
                $ionicLoading.hide();
                errorService.showAlert(data);
                deferred.reject('pdt_modal_evo_error'); // Mostramos el error localizado 
            }); 
            promise.success = function(fn) {
                promise.then(fn);
                return promise;
            }
            promise.error = function(fn) {
                promise.then(null, fn);
                return promise;
            }
            return promise;
        }

    }
})
.service('errorService', function($ionicPopup, $translate, $state){
    return {
        showAlert: function(data){
            if (data == null) {
                var alertPopup = $ionicPopup.alert({
                    title: 'Error',
                    template: $translate('error_no_data')
                });
            }
            else if (data.status==401) {
                $state.go('logout');  
                var alertPopup = $ionicPopup.alert({
                    title: 'Error',
                    template: $translate('error_401')
                });
            }
            else if (data.status==403) {
                $state.go('logout');  
                var alertPopup = $ionicPopup.alert({
                    title: 'Error',
                    template: $translate('error_403')
                });
            } else if(data.status==500){
                var alertPopup = $ionicPopup.alert({
                    title: 'Error',
                    template: $translate('error_500')
                });
            }
        },
        showAlertLogin: function(data){ 
            if (data == null) {
                var alertPopup = $ionicPopup.alert({
                    title: 'Error',
                    template: $translate('error_no_data')
                });
            }
            else if (data.status==404) {
                var alertPopup = $ionicPopup.alert({
                    title: 'Error',
                    template: $translate('login_error')
                });
            }
        },
        showAlertAgendamiento: function(status){
            if (status == null) {
                var alertPopup = $ionicPopup.alert({
                    title: 'Error',
                    template: $translate('error_no_data')
                });
            }
            else if (status == 500){
                $ionicPopup.alert({
                    title: 'Error',
                    template: $translate('error_500')
                });
            }
        }
    }
})
.service('localstorage', ['$window', function($window){
    return {
        set: function(key, value) {
            $window.localStorage[key] = value;
        },
        get:function(key, defaultValue){
            return $window.localStorage[key] || defaultValue;
        },
        setObject: function(key, value){
            $window.localStorage[key] = JSON.stringify(value);
        },
        getObject: function(key){
            return JSON.parse($window.localStorage[key] || '{}');
        },
        removeItem: function(key){
            $window.localStorage.removeItem(key);
        }
    }
}])
.service('Camera', ['$q', function($q) {
  return {
    getPicture: function(options) {
      var q = $q.defer();

      navigator.camera.getPicture(function(result) {
        // Do any magic you need
        q.resolve(result);
      }, function(err) {
        q.reject(err);
      }, options);

      return q.promise;
    }
  }
}])

.service('PictureService', function($q, $http, $translate, errorService, $cordovaFileTransfer, $ionicPlatform) {
    return {
        uploadPicture: function(token, id_paciente, image) {
            var deferred = $q.defer();
            var promise = deferred.promise;

            $ionicPlatform.ready(function() {
                var server = window.DL_API_URL+'api/2/clients/'+id_paciente+'/upload_picture',
                    params = {};

                params.key = token;

                var options = {
                    fileKey: "picture",
                    fileName: image.substr(image.lastIndexOf('/') + 1),
                    chunkedMode: false,
                    mimeType: "image/jpeg"
                };
                options.params = params;

                $cordovaFileTransfer.upload(server, image, options)
                  .then(function(result) {
                    deferred.resolve(result);
                  }, function(err) {
                    deferred.reject(err);
                  }, function (progress) {
                    console.log(progress);
                    //uploading_perc = progress.loaded / progress.total + "%"; // constant progress updates
                  });

            });
              
            promise.success = function(fn) {
                promise.then(fn);
                return promise;
            }
            promise.error = function(fn) {
                promise.then(null, fn);
                return promise;
            }
            return promise;
        }
    }
})

.service( 'HardwareBackButtonManager', function($ionicPlatform, $state, $ionicHistory){
  this.deregister = undefined;

  this.disable = function(){
    this.deregister = $ionicPlatform.registerBackButtonAction(function(e){
    e.preventDefault();
    navigator.app.exitApp();
    }, 101);
  }

  this.enable = function(){
    if( this.deregister !== undefined ){
      this.deregister();
      this.deregister = undefined;
    }
  }
  this.goHome = function(){
    this.deregister = $ionicPlatform.registerBackButtonAction(function(e){
        $ionicHistory.nextViewOptions({
            disableBack: true,
            disableAnimate: true
          });
        $state.go('app.agenda');
    }, 101);
  }
  return this;
})

;
